==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/workflowengine/l10n/hu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Unable to retrieve the group list" : "Csoportlista betöltése sikertelen",
    "Saved" : "Elmentve",
    "Saving failed:" : "Mentés sikertelen:",
    "File MIME type" : "Fájl MIME típus",
    "is" : "ez",
    "is not" : "nem ez",
    "matches" : "egyezik",
    "does not match" : "nem egyezik",
    "Example: {placeholder}" : "Például: {placeholder}",
    "File size (upload)" : "Fájl méret (feltöltés)",
    "less" : "kisebb",
    "less or equals" : "kisebb vagy egyenlő",
    "greater or equals" : "nagyobb vagy egyenlő",
    "greater" : "nagyobb",
    "File system tag" : "Fájlrendszer címke",
    "is tagged with" : "címkézve ezzel",
    "is not tagged with" : "nem címkézve ezzel",
    "Select tag…" : "Címke választás...",
    "Request remote address" : "Távoli cím kérés",
    "matches IPv4" : "IPv4 egyezik",
    "does not match IPv4" : "IPv4 nem egyezik",
    "matches IPv6" : "IPv6 egyezik",
    "does not match IPv6" : "IPv6 nem egyezik",
    "Request time" : "Idő kérés",
    "between" : "közötte",
    "not between" : "nincs közötte",
    "Start" : "Kezdet",
    "End" : "Vég",
    "Select timezone…" : "Időzóna választás...",
    "Request URL" : "URL kérés",
    "Predefined URLs" : "Elődefiniált URL-ek",
    "Files WebDAV" : "WebDAV fálok",
    "Request user agent" : "Böngésző kérés",
    "Sync clients" : "Szinkron kliensek",
    "Android client" : "Android kliens",
    "iOS client" : "iOS klens",
    "Desktop client" : "Asztali kliens",
    "User group membership" : "Felhasználói csoport tagság",
    "is member of" : "tagja ennek",
    "is not member of" : "nem tagja ennek",
    "The given operator is invalid" : "A megadott operátor érvénytelen",
    "The given regular expression is invalid" : "A megadott reguláris kifejezés érvénytelen",
    "The given file size is invalid" : "A megadott fájlméret érvénytelen",
    "The given tag id is invalid" : "A megadott címe azonosító érvénytelen",
    "The given IP range is invalid" : "A megadott IP tartomány érvénytelen",
    "The given IP range is not valid for IPv4" : "A megadott IPv4 tartomány nem érvényes",
    "The given IP range is not valid for IPv6" : "A megadott IPv6 tartomány nem érvényes",
    "The given time span is invalid" : "A megadott időtartam nem érvényes",
    "The given start time is invalid" : "A megadott kezdő idő nem érvényes",
    "The given end time is invalid" : "A megadott vég idő nem érvényes",
    "The given group does not exist" : "A megadott csoport nem létezik",
    "Check %s is invalid or does not exist" : "%s érvénytelen vagy nem létezik, ellenőrizd",
    "Operation #%s does not exist" : "#%s művelet nem létezik",
    "Operation %s does not exist" : "%s művelet nem létezik",
    "Operation %s is invalid" : "#%s művelet érvénytelen",
    "Check %s does not exist" : "%s nem létezik, ellenőrizd",
    "Check %s is invalid" : "%s érvénytelen, ellenőrizd",
    "Check #%s does not exist" : "#%s nem létezik, ellenőrizd",
    "Workflow" : "Munkafolyamat",
    "Files workflow engine" : "Fájl munkafolyamat motor",
    "Open documentation" : "Dokumentáció megnyitása",
    "Add rule group" : "Szabály csoport hozzáadás",
    "Short rule description" : "A szabály rövid leírása",
    "Add rule" : "Szabály hozzáadás",
    "Reset" : "Visszaállítás",
    "Save" : "Mentés",
    "Saving…" : "Mentés...",
    "Loading…" : "Betöltés..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/workflowengine/l10n/hu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "A szabály rövid leírása",
    "Add rule" : "Szabály hozzáadás",
    "Reset" : "Visszaállítás",
    "Save" : "Mentés",
    "Saving…" : "Mentés...",
    "Group list is empty" : "Csoport lista üres",
    "Unable to retrieve the group list" : "Csoportlista betöltése sikertelen",
    "Saved" : "Elmentve",
    "Saving failed:" : "Mentés sikertelen:",
    "Add rule group" : "Szabály csoport hozzáadás",
    "File MIME type" : "Fájl MIME típus",
    "is" : "ez",
    "is not" : "nem ez",
    "matches" : "egyezik",
    "does not match" : "nem egyezik",
    "Example: {placeholder}" : "Például: {placeholder}",
    "File name" : "Fájlnév",
    "File size (upload)" : "Fájl méret (feltöltés)",
    "less" : "kisebb",
    "less or equals" : "kisebb vagy egyenlő",
    "greater or equals" : "nagyobb vagy egyenlő",
    "greater" : "nagyobb",
    "File system tag" : "Fájlrendszer címke",
    "is tagged with" : "címkézve ezzel",
    "is not tagged with" : "nem címkézve ezzel",
    "Select tag…" : "Címke választás...",
    "Request remote address" : "Távoli cím kérés",
    "matches IPv4" : "IPv4 egyezik",
    "does not match IPv4" : "IPv4 nem egyezik",
    "matches IPv6" : "IPv6 egyezik",
    "does not match IPv6" : "IPv6 nem egyezik",
    "Request time" : "Idő kérés",
    "between" : "közötte",
    "not between" : "nincs közötte",
    "Start" : "Kezdet",
    "End" : "Vég",
    "Select timezone…" : "Időzóna választás...",
    "Request URL" : "URL kérés",
    "Predefined URLs" : "Elődefiniált URL-ek",
    "Files WebDAV" : "WebDAV fálok",
    "Request user agent" : "Böngésző kérés",
    "Sync clients" : "Szinkron kliensek",
    "Android client" : "Android kliens",
    "iOS client" : "iOS klens",
    "Desktop client" : "Asztali kliens",
    "Thunderbird & Outlook addons" : "Thunderbird és Outlook bővítmények",
    "User group membership" : "Felhasználói csoport tagság",
    "is member of" : "tagja ennek",
    "is not member of" : "nem tagja ennek",
    "The given operator is invalid" : "A megadott operátor érvénytelen",
    "The given regular expression is invalid" : "A megadott reguláris kifejezés érvénytelen",
    "The given file size is invalid" : "A megadott fájlméret érvénytelen",
    "The given tag id is invalid" : "A megadott címe azonosító érvénytelen",
    "The given IP range is invalid" : "A megadott IP tartomány érvénytelen",
    "The given IP range is not valid for IPv4" : "A megadott IPv4 tartomány nem érvényes",
    "The given IP range is not valid for IPv6" : "A megadott IPv6 tartomány nem érvényes",
    "The given time span is invalid" : "A megadott időtartam nem érvényes",
    "The given start time is invalid" : "A megadott kezdő idő nem érvényes",
    "The given end time is invalid" : "A megadott vég idő nem érvényes",
    "The given group does not exist" : "A megadott csoport nem létezik",
    "Check %s is invalid or does not exist" : "%s érvénytelen vagy nem létezik, ellenőrizd",
    "Operation #%s does not exist" : "#%s művelet nem létezik",
    "Operation %s does not exist" : "%s művelet nem létezik",
    "Operation %s is invalid" : "#%s művelet érvénytelen",
    "Check %s does not exist" : "%s nem létezik, ellenőrizd",
    "Check %s is invalid" : "%s érvénytelen, ellenőrizd",
    "Check #%s does not exist" : "#%s nem létezik, ellenőrizd",
    "Workflow" : "Munkafolyamat",
    "Files workflow engine" : "Fájl munkafolyamat motor",
    "Open documentation" : "Dokumentáció megnyitása",
    "Loading…" : "Betöltés..."
},
"nplurals=2; plural=(n != 1);");
